
;**************************************************************************
;*                             Plasic Krtka III.                          *
;**************************************************************************
;*                            v 2.09 - 16.12.2014                         *
;**************************************************************************
;*          Hardw.: PIC12F675 used                                        *
;*          OSC.......: Internal osc. used     POWER.....:  5V 7805       *
;**************************************************************************


;--------------------------------------------------------
;Pins connection:
;----------------------
;GP0 --> signal output
;GP1 --> LED output
;GP2 --> N/C
;GP3 --> N/C
;GP4, GP5: NF frequency selection:
;      GP4	GP5	Fq
;      ---	---	------
;	1	1	300 Hz
;	0	1	275 Hz
;	1	0	400 Hz
;	0	0	240 Hz
;--------------------------------------------------------
;--------------------------------------------------------

W                            EQU     H'0000'
F                            EQU     H'0001'


 INCLUDE "P12F675.INC"




;	__CONFIG        _BODEN_OFF & _CP_OFF & _DATA_CP_OFF & _PWRTE_ON & _WDT_OFF & _LVP_OFF & _MCLRE_ON & _INTRC_OSC_NOCLKOUT


_U001			     EQU     B'00000110100100'		;MCLR = reset
_U002			     EQU     B'00000110000100'		;MCLR = input

	__CONFIG        _U002

;==========================================================================
;       Variable Definition
;==========================================================================

TIMER1		EQU	H'20'		;Used in delay routine
TIMER2		EQU	H'21'		; "	"	"	
TIMER3		equ	H'22'		;

v_cnt		equ	H'23'

v_cnta		equ	H'24'
v_cntb		equ	H'25'

v_mfv		equ	H'26'

v_cntx		equ	H'27'
;==========================================================================

		ORG	0		;Reset vector address
		GOTO	RESET		;goto RESET routine when boot.

;XXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXX
;XXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXX


;----------------------------------------------------------------------------
;----------------------------------------------------------------------------
;
;	       **********************************
;              **  RESET :  main boot routine  **
;              **********************************

RESET		MOVLW	B'00000111'	;Disable Comparator module's
		MOVWF	CMCON
		;
		BSF	STATUS,RP0	;Switch to register bank 1
					;Disable pull-ups
					;INT on rising edge
					;TMR0 to CLKOUT
					;TMR0 Incr low2high trans.
					;Prescaler assign to Timer0
					;Prescaler rate is 1:256
		MOVLW	B'01010111'	;Set PIC options (See datasheet).
		MOVWF	OPTION_REG	;Write the OPTION register.
		;
		CLRF	INTCON		;Disable interrupts

		MOVLW	B'11111100'	;GP0 - 1 = output
		MOVWF	TRISIO

		clrf	ANSEL
		movlw	B'11111111'
		movwf	WPU

		BCF	STATUS,RP0	;Switch Back to reg. Bank 0

;----------------------------------------------------------------------------
;XXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXX
;----------------------------------------------------------------------------
;----------------------------------------------------------------------------
;                             Main Loop
;----------------------------------------------------------------------------
;----------------------------------------------------------------------------
;XXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXX
;----------------------------------------------------------------------------
main		call	beep_6s
		call	wait_10s

		call	beep_2s
		call	wait_20s

		call	beep_4s
		call	wait_60s

		call	beep_6s
		call	wait_120s

		call	beep_2s
		call	wait_10s

		call	beep_4s
		call	wait_10s

		call	beep_2s
		call	wait_180s

		call	beep_6s
		call	wait_20s

		call	beep_4s
		call	wait_60s


		goto	main
;----------------------------------------------------------------------------
;XXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXX
;XXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXX
;----------------------------------------------------------------------------
;                         end of main loop
;----------------------------------------------------------------------------
;XXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXX
;XXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXX
;----------------------------------------------------------------------------



;----------------------------------------------------------------------------
;----------------------------------------------------------------------------
beep_2s		movlw	D'004'
		goto	beep_main
;----------------------------------------------------------------------------
beep_4s		movlw	D'008'
		goto	beep_main
;----------------------------------------------------------------------------
beep_6s		movlw	D'012'
		goto	beep_main
;----------------------------------------------------------------------------
;----------------------------------------------------------------------------
; NF-generator - main
;----------------------------------------------------------------------------
;----------------------------------------------------------------------------
beep_main	movwf	v_cntx

		movf	v_cntx,0
		call	beep_m1

		movf	v_cntx,0
		call	beep_m2

		movf	v_cntx,0
		call	beep_m3

		movf	v_cntx,0
		call	beep_m4

		movf	v_cntx,0
		call	beep_m5

		return
;----------------------------------------------------------------------------
;----------------------------------------------------------------------------
;----------------------------------------------------------------------------
beep_m1		movwf	v_cnta
		bsf	GPIO,D'001'		;LED on

il01		movlw	D'167'
		movwf	v_cntb

il02		bsf	GPIO,D'000'
		call	dr_1p5ms
		bcf	GPIO,D'000'
		call	dr_1p5ms

		decfsz	v_cntb,1
		goto	il02

		decfsz	v_cnta,1
		goto	il01

		bcf	GPIO,D'001'		;LED off
		return
;----------------------------------------------------------------------------
beep_m2		movwf	v_cnta
		bsf	GPIO,D'001'		;LED on

xil01		movlw	D'167'
		movwf	v_cntb

xil02		bsf	GPIO,D'000'
		call	dr_1p0ms
		bcf	GPIO,D'000'
		call	dr_1p0ms

		decfsz	v_cntb,1
		goto	xil02

		decfsz	v_cnta,1
		goto	xil01

		bcf	GPIO,D'001'		;LED off
		return
;----------------------------------------------------------------------------
beep_m3		movwf	v_cnta
		bsf	GPIO,D'001'		;LED on

yil01		movlw	D'167'
		movwf	v_cntb

yil02		bsf	GPIO,D'000'
		call	dr_3p0ms
		bcf	GPIO,D'000'
		call	dr_3p0ms

		decfsz	v_cntb,1
		goto	yil02

		decfsz	v_cnta,1
		goto	yil01

		bcf	GPIO,D'001'		;LED off
		return

;----------------------------------------------------------------------------
beep_m4		movwf	v_cnta
		bsf	GPIO,D'001'		;LED on

gil01		movlw	D'167'
		movwf	v_cntb

gil02		bsf	GPIO,D'000'
		call	dr_6p0ms
		bcf	GPIO,D'000'
		call	dr_6p0ms

		decfsz	v_cntb,1
		goto	gil02

		decfsz	v_cnta,1
		goto	gil01

		bcf	GPIO,D'001'		;LED off
		return

;----------------------------------------------------------------------------
beep_m5		movwf	v_cnta
		bsf	GPIO,D'001'		;LED on

hil01		movlw	D'167'
		movwf	v_cntb

hil02		bsf	GPIO,D'000'
		call	dr_4p5ms
		bcf	GPIO,D'000'
		call	dr_4p5ms

		decfsz	v_cntb,1
		goto	hil02

		decfsz	v_cnta,1
		goto	hil01

		bcf	GPIO,D'001'		;LED off
		return

;----------------------------------------------------------------------------
;----------------------------------------------------------------------------
;----------------------------------------------------------------------------
;----------------------------------------------------------------------------
wait_10s	movlw	D'010'
		goto	m_wait
;----------------------------------------------------------------------------
wait_20s	movlw	D'020'
		goto	m_wait
;----------------------------------------------------------------------------
wait_30s	movlw	D'030'
		goto	m_wait
;----------------------------------------------------------------------------
wait_60s	movlw	D'060'
		goto	m_wait
;----------------------------------------------------------------------------
wait_120s	movlw	D'120'
		goto	m_wait
;----------------------------------------------------------------------------
wait_180s	movlw	D'180'
		goto	m_wait
;----------------------------------------------------------------------------
;----------------------------------------------------------------------------
m_wait		movwf	v_cnta
il05		call	wait_1s
		decfsz	v_cnta,1
		goto	il05
		return
;----------------------------------------------------------------------------
;----------------------------------------------------------------------------
wait_1s		bsf	GPIO,D'001'
		call	dr_200ms
		bcf	GPIO,D'001'
		call	dr_200ms
		bsf	GPIO,D'001'
		call	dr_200ms
		bcf	GPIO,D'001'
		call	dr_200ms
		bsf	GPIO,D'001'
		call	dr_200ms
		bcf	GPIO,D'001'
		call	dr_200ms
		return
;----------------------------------------------------------------------------
;----------------------------------------------------------------------------
;----------------------------------------------------------------------------
;GP4, GP5: NF frequency selection:
;      GP4	GP5	Fq
;      ---	---	------
;	1	1	300 Hz
;	0	1	275 Hz
;	1	0	400 Hz
;	0	0	240 Hz
;--------------------------------------------------------
init_frq	movlw	D'200'			;if GP4 = GP5 = 1: default: 300 Hz
		btfss	GPIO,D'004'
		goto	x01
		btfss	GPIO,D'005'
		movlw	D'150'			;GP4 = 1 & GP5 = 0 --> Fq = 400 Hz
		movwf	v_mfv
		return

x01		movlw	D'220'			;GP4 = 0 & if GP5 = 1 --> Fq = 260 Hz
		btfss	GPIO,D'005'
		movlw	D'250'			;GP4 = 0 & GP5 = 0 --> Fq = 240 Hz
		movwf	v_mfv
		return
;XXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXX
;XXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXX

;		*********************************************
;		*               delay routine               *
;		*********************************************

dr001		MOVLW   D'255'
		MOVWF   TIMER2
DEL_LOOP1	MOVLW   D'255'
		MOVWF   TIMER1
DEL_LOOP2	DECFSZ  TIMER1,F
		GOTO    DEL_LOOP2
		DECFSZ  TIMER2,F
		GOTO    DEL_LOOP1
		return
;-----------------------------------------------------------------
;-----------------------------------------------------------------
;-----------------------------------------------------------------
dr_1p0ms	call	init_frq
		MOVLW   D'001'
		MOVWF   TIMER2
DEL_LOOP10	movf	v_mfv,0
		MOVWF   TIMER1
DEL_LOOP11	DECFSZ  TIMER1,F	;1us
		GOTO    DEL_LOOP11	;2us
		DECFSZ  TIMER2,F
		GOTO    DEL_LOOP10
		return
;-----------------------------------------------------------------
dr_1p5ms	call	init_frq
		MOVLW   D'003'
		MOVWF   TIMER2
xDEL_LOOP10	movf	v_mfv,0
		MOVWF   TIMER1
xDEL_LOOP11	DECFSZ  TIMER1,F	;1us
		GOTO    xDEL_LOOP11	;2us
		DECFSZ  TIMER2,F
		GOTO    xDEL_LOOP10
		return
;-----------------------------------------------------------------
dr_3p0ms	call	init_frq
		MOVLW   D'006'
		MOVWF   TIMER2
yDEL_LOOP10	movf	v_mfv,0
		MOVWF   TIMER1
yDEL_LOOP11	DECFSZ  TIMER1,F	;1us
		GOTO    yDEL_LOOP11	;2us
		DECFSZ  TIMER2,F
		GOTO    yDEL_LOOP10
		return
;-----------------------------------------------------------------
dr_6p0ms	call	init_frq
		MOVLW   D'012'
		MOVWF   TIMER2
gDEL_LOOP10	movf	v_mfv,0
		MOVWF   TIMER1
gDEL_LOOP11	DECFSZ  TIMER1,F	;1us
		GOTO    gDEL_LOOP11	;2us
		DECFSZ  TIMER2,F
		GOTO    gDEL_LOOP10
		return
;-----------------------------------------------------------------
dr_4p5ms	call	init_frq
		MOVLW   D'009'
		MOVWF   TIMER2
hDEL_LOOP10	movf	v_mfv,0
		MOVWF   TIMER1
hDEL_LOOP11	DECFSZ  TIMER1,F	;1us
		GOTO    hDEL_LOOP11	;2us
		DECFSZ  TIMER2,F
		GOTO    hDEL_LOOP10
		return
;-----------------------------------------------------------------
;-----------------------------------------------------------------
;-----------------------------------------------------------------
dr_200ms	call	dr_100ms
		call	dr_100ms
		return
;-----------------------------------------------------------------
;-----------------------------------------------------------------
dr_100ms	MOVLW   D'199'
		MOVWF   TIMER2
DEL_LOOP3	MOVLW   D'167'
		MOVWF   TIMER1
DEL_LOOP4	DECFSZ  TIMER1,F	;1us
		GOTO    DEL_LOOP4	;2us
		DECFSZ  TIMER2,F
		GOTO    DEL_LOOP3
		return
;-----------------------------------------------------------------
;-----------------------------------------------------------------
dr_1s		movlw	D'010'
		movwf	TIMER3
del_loop5	call	dr_100ms
		decfsz	TIMER3,1
		goto	del_loop5

		return
;XXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXX

		END